# -*- coding: utf-8 -*-

################################################################################
## Form generated from reading UI file 'runner.ui'
##
## Created by: Qt User Interface Compiler version 5.15.1
##
## WARNING! All changes made in this file will be lost when recompiling UI file!
################################################################################

from PySide2.QtCore import *
from PySide2.QtGui import *
from PySide2.QtWidgets import *


class Ui_RunDialog(object):
    def setupUi(self, RunDialog):
        if not RunDialog.objectName():
            RunDialog.setObjectName(u"RunDialog")
        RunDialog.resize(700, 400)
        self.gridLayout_2 = QGridLayout(RunDialog)
        self.gridLayout_2.setObjectName(u"gridLayout_2")
        self.gridLayout = QGridLayout()
        self.gridLayout.setObjectName(u"gridLayout")
        self.horizontalLayout = QHBoxLayout()
        self.horizontalLayout.setObjectName(u"horizontalLayout")
        self.horizontalSpacer = QSpacerItem(40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.horizontalLayout.addItem(self.horizontalSpacer)

        self.btnOk = QPushButton(RunDialog)
        self.btnOk.setObjectName(u"btnOk")

        self.horizontalLayout.addWidget(self.btnOk)

        self.btnClose = QPushButton(RunDialog)
        self.btnClose.setObjectName(u"btnClose")

        self.horizontalLayout.addWidget(self.btnClose)

        self.horizontalSpacer_2 = QSpacerItem(40, 20, QSizePolicy.Expanding, QSizePolicy.Minimum)

        self.horizontalLayout.addItem(self.horizontalSpacer_2)


        self.gridLayout.addLayout(self.horizontalLayout, 3, 0, 1, 1)

        self.placeholder = QLabel(RunDialog)
        self.placeholder.setObjectName(u"placeholder")
        sizePolicy = QSizePolicy(QSizePolicy.MinimumExpanding, QSizePolicy.Minimum)
        sizePolicy.setHorizontalStretch(0)
        sizePolicy.setVerticalStretch(0)
        sizePolicy.setHeightForWidth(self.placeholder.sizePolicy().hasHeightForWidth())
        self.placeholder.setSizePolicy(sizePolicy)
        self.placeholder.setAlignment(Qt.AlignCenter)

        self.gridLayout.addWidget(self.placeholder, 0, 0, 1, 1)

        self.progressBar = QProgressBar(RunDialog)
        self.progressBar.setObjectName(u"progressBar")
        self.progressBar.setValue(0)
        self.progressBar.setTextVisible(True)

        self.gridLayout.addWidget(self.progressBar, 2, 0, 1, 1)

        self.verticalSpacer = QSpacerItem(20, 40, QSizePolicy.Minimum, QSizePolicy.Expanding)

        self.gridLayout.addItem(self.verticalSpacer, 1, 0, 1, 1)


        self.gridLayout_2.addLayout(self.gridLayout, 0, 0, 1, 1)


        self.retranslateUi(RunDialog)

        QMetaObject.connectSlotsByName(RunDialog)
    # setupUi

    def retranslateUi(self, RunDialog):
        RunDialog.setWindowTitle(QCoreApplication.translate("RunDialog", u"Dialog", None))
        self.btnOk.setText(QCoreApplication.translate("RunDialog", u"Run", None))
        self.btnClose.setText(QCoreApplication.translate("RunDialog", u"Close", None))
        self.placeholder.setText(QCoreApplication.translate("RunDialog", u"placeholder", None))
        self.progressBar.setFormat("")
    # retranslateUi




import math
import os
import sys

from PySide2 import QtWidgets, QtGui, QtCore

import xappt

from xappt_qt.gui.ui.browser import Ui_Browser
from xappt_qt.gui.delegates import SimpleItemDelegate
from xappt_qt.dark_palette import apply_palette
from xappt_qt.constants import *

# noinspection PyUnresolvedReferences
from xappt_qt.gui.resources import icons


class XapptBrowser(QtWidgets.QMainWindow, Ui_Browser):
    ROLE_TOOL_CLASS = QtCore.Qt.UserRole + 1

    def __init__(self):
        super().__init__()
        self.setupUi(self)
        self.setWindowIcon(QtGui.QIcon(":appicon"))
        self.populate_tools()
        self.treeTools.setItemDelegate(SimpleItemDelegate())
        self.treeTools.itemActivated.connect(self.item_activated)
        self.treeTools.currentItemChanged.connect(self.item_changed)
        self.interfaces = []

    def populate_tools(self):
        for tool_name, tool_class in xappt.registered_tools():
            item = QtWidgets.QTreeWidgetItem()
            item.setText(0, tool_name)
            item.setData(0, self.ROLE_TOOL_CLASS, tool_class)
            self.treeTools.addTopLevelItem(item)
        self.treeTools.sortItems(0, QtCore.Qt.AscendingOrder)

    def item_activated(self, item: QtWidgets.QTreeWidgetItem, column: int):
        tool_class = item.data(0, self.ROLE_TOOL_CLASS)
        interface = xappt.get_interface()
        self.interfaces.append(interface)
        interface.invoke(tool_class())

    def item_changed(self, current_item: QtWidgets.QTreeWidgetItem, previous_item: QtWidgets.QTreeWidgetItem):
        tool_class = current_item.data(0, self.ROLE_TOOL_CLASS)  # type: xappt.models.BaseTool
        if tool_class.help() == "":
            help_text = "No help text is available for this tool."
        else:
            help_text = f"{tool_class.name()}: {tool_class.help()}"
        self.labelHelp.setText(help_text)

    def closeEvent(self, event: QtGui.QCloseEvent):
        self.interfaces.clear()


def main(args) -> int:
    app = QtWidgets.QApplication.instance() or QtWidgets.QApplication(args)
    apply_palette(app)

    browser = XapptBrowser()
    browser.show()

    app.setProperty(APP_PROPERTY_RUNNING, True)
    return app.exec_()


def entry_point() -> int:
    os.environ[xappt.INTERFACE_ENV] = APP_INTERFACE_NAME
    return main(sys.argv)


if __name__ == '__main__':
    sys.exit(entry_point())



from typing import Optional

from PySide2 import QtWidgets, QtCore, QtGui

from xappt import BaseTool

from xappt_qt.gui.tool_page import ToolPage
from xappt_qt.gui.ui.runner import Ui_RunDialog

# noinspection PyUnresolvedReferences
from xappt_qt.gui.resources import icons


class RunDialog(QtWidgets.QDialog, Ui_RunDialog):
    def __init__(self):
        super().__init__()
        self.setupUi(self)

        self.placeholder.setVisible(False)

        flags = QtCore.Qt.Window
        flags |= QtCore.Qt.WindowCloseButtonHint
        flags |= QtCore.Qt.WindowMinimizeButtonHint
        self.setWindowFlags(flags)
        self.setWindowIcon(QtGui.QIcon(":appicon"))

        self.tool_plugin: Optional[BaseTool] = None
        self.tool_widget: Optional[ToolPage] = None

    def clear(self):
        if self.tool_widget is not None:
            index = self.gridLayout.indexOf(self.tool_widget)
            self.gridLayout.takeAt(index)
            self.tool_widget.deleteLater()
            self.tool_widget = None
            self.tool_plugin = None
        self.btnOk.setEnabled(True)

    def set_current_tool(self, tool_plugin: BaseTool):
        if self.tool_widget is not None:
            raise RuntimeError("Clear RunDialog before adding a new tool.")
        self.tool_plugin = tool_plugin
        self.tool_widget = ToolPage(self.tool_plugin)
        self.gridLayout.addWidget(self.tool_widget, 0, 0)
        self.setWindowTitle(tool_plugin.name())
        self.tool_widget.setEnabled(True)
